@@ -68,6 +68,42 @@ class _TestDatabase(object):
         writer.flush()
         assert len(reader) == 2
 
+    def test_transactions(self):
+
+        class FS(xodb.Schema):
+            language = 'en'
+            x = xodb.Integer.named('x')
+
+        class F(object):
+            x = 9
+
+        def _writer():
+            db = xodb.temp()
+            db.map(F, FS)
+            return db
+
+        writer = _writer()
+        f = F()
+        j = F()
+        assert not writer.count()
+        with writer.transaction() as db:
+            db.add(f)
+        assert writer.count() == 1
+
+        with writer.transaction() as db:
+            db.add(j)
+            raise Exception("boo!")
+        assert writer.count() == 1
+
+        with writer.transaction() as db:
+            del db['XX:9']
+            raise Exception("boo!")
+        assert writer.count() == 1
+
+        with writer.transaction() as db:
+            del db['XX:9']
+        assert writer.count() == 0
+
     def test_stored_values(self):
         db = self.db
         assert db.value_count == 0
