@@ -49,7 +49,11 @@ __all__ = [
     ]
 
 
-def open(path_or_db, writable=True, overwrite=False, spelling=True):
+def open(path_or_db,
+         writable=True,
+         overwrite=False,
+         spelling=True,
+         replicated=False):
     """Return an xodb database with the given path or xapian database object.
 
     :param path_or_db: A path to a database file or a pre-existing
@@ -64,7 +68,10 @@ def open(path_or_db, writable=True, overwrite=False, spelling=True):
     database.
     """
     return Database(path_or_db,
-                    writable=writable, overwrite=overwrite, spelling=spelling)
+                    writable=writable,
+                    overwrite=overwrite,
+                    spelling=spelling,
+                    replicated=replicated)
 
 
 def temp(spelling=True):
@@ -75,3 +82,9 @@ def temp(spelling=True):
     """
     return open(tempfile.mkdtemp(), spelling=spelling)
 
+
+def inmemory():
+    """Returns an xodb database backed by an in-memory xapian
+    database.  Does not support spelling correction.
+    """
+    return open(xapian.inmemory_open(), spelling=False)
