@@ -47,6 +47,7 @@ def _prefix(name):
 
 
 class Record(object):
+    """Nice attribute-accessable record for a search result."""
 
     def __init__(self, schema):
         self._xodb_schema = schema
@@ -105,6 +106,7 @@ class LanguageDecider(xapian.ExpandDecider):
 
 
 class PrefixDecider(xapian.ExpandDecider):
+    """Expand decider to only match terms that begin with a prefix."""
 
     __slots__ = ['prefix']
 
@@ -338,6 +340,10 @@ class Database(object):
         return added
 
     def to_schema(self, obj, validate=True):
+        """
+        Turn an object into an schema instance which is fully
+        populated with data from the object.  Optionally validate.
+        """
         if hasattr(obj, '__xodb_schema__'):
             schema_type = obj.__xodb_schema__
         else:
@@ -357,11 +363,17 @@ class Database(object):
         return schema
 
     def to_document(self, obj, validate=True):
+        """
+        Convienient wrapper that does the object->schema->document
+        transformation.
+        """
         schema = self.to_schema(obj, validate)
         return self.doc_from_dict(schema.memo.dict)
 
     def doc_from_dict(self, data):
-        """
+        """Take an intermediate representation of a document (a
+        "memo") and turn it into a xapian document.  The document is
+        returned and not added to the database.
         """
         doc = xapian.Document()
 
@@ -428,6 +440,10 @@ class Database(object):
         return doc
 
     def reopen(self):
+        """
+        Reopen the database.  Called before most query methods.  If
+        replication is used, the db is closed and reopened.
+        """
         if not self.replicated:
             self.backend.reopen()
         else:
@@ -440,8 +456,8 @@ class Database(object):
         self.refresh_metadata()
 
     def refresh_metadata(self):
-        """Reopen the database, refresing the local connection's view
-        of the prefix and value data.
+        """Refresh the local connection's view of the prefix and value
+        data.
         """
         try:
             keys = self.backend.metadata_keys()
@@ -477,30 +493,37 @@ class Database(object):
             if self._writable:
                 self.value_count = 0
 
+    # FIXME:mp the transactional methods noop for backends that don't
+    # support transaction (only inmemory to date) perhaps support for
+    # those backends should be dropped.
+
     def begin(self):
         if self._writable:
             self.backend.reopen()
             try:
                 self.backend.begin_transaction()
-            except:
+            except Exception:
                 pass # noop for backends that don't support transactions
 
     def cancel(self):
         if self._writable:
             try:
                 self.backend.cancel_transaction()
-            except:
+            except Exception:
                 pass
 
     def commit(self):
         if self._writable:
             try:
                 self.backend.commit_transaction()
-            except:
+            except Exception:
                 pass
 
     def prepare_query_parser(self, language=None,
                              default_op=Query.OP_AND):
+        """
+        Setup a query parser with the current known prefixes and values.
+        """
         qp = QueryParser()
         qp.set_database(self.backend)
         qp.set_default_op(default_op)
@@ -668,6 +691,9 @@ class Database(object):
                translit='translit/long',
                default_op=Query.OP_AND,
                parser_flags=default_parser_flags):
+        """
+        Expand a query on a given set of prefixes.
+        """
 
         q = self.querify(query, language, translit, default_op, parser_flags)
         results = {}
@@ -706,7 +732,8 @@ class Database(object):
         given query.
 
         Limit tells the estimator the minimum number of documents to
-        consider.  A zero limit means check all documents in the db."""
+        consider.  A zero limit means potentially check all documents
+        in the db."""
         self.reopen()
         enq = xapian.Enquire(self.backend)
 
