@@ -130,7 +130,8 @@ class Schema(schema.Form):
         name = element.flattened_name()
         memo = self._memo
         if term:
-            term = term.lower()
+            if element.lower:
+                term = term.lower()
             if element.prefix:
                 memo.add_term(_prefix(name, term), element.boolean)
             else:
@@ -189,7 +190,8 @@ class Schema(schema.Form):
 
         if element.string:
             if value:
-                term = value.lower()
+                if element.lower:
+                    term = value.lower()
                 if element.string_prefix:
                     memo.add_term(_prefix(element.string_prefix, term),
                                    element.boolean)
@@ -293,6 +295,10 @@ class _BaseElement(object):
     sortable value.
     """
 
+    lower = True
+    """Whether to lowercase the value when indexing the element's term.
+    """
+
     @classmethod
     def property(cls, fn):
         """Decorator for wrapping a schema class method getter with an
